from .RayleighDampingByFrequencyComponent import RayleighDampingByFrequencyComponent


class RayleighDampingByFrequencyComponentArray(
    list[RayleighDampingByFrequencyComponent]
):
    def findAt(self):
        pass
